# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov ^%{python2_sitearch}/.*\\\.so$

%define oname	pwquality

%define major	1
%define libname %mklibname %{oname} %{major}
%define devname	%mklibname %{oname} -d

Summary:	Library for password quality checking and generating random passwords
Name:		libpwquality
Version:	1.3.0
Release:	%mkrel 4
# The package is BSD licensed with option to relicense as GPL+
# - this option is redundant as the BSD license allows that anyway.
License:	BSD or GPL+
Group:		System/Libraries
URL:		https://fedorahosted.org/libpwquality/
Source0:	http://fedorahosted.org/releases/l/i/libpwquality/libpwquality-%{version}.tar.bz2
Patch0:		libpwquality-1.3.0-python-linking.patch
BuildRequires:	gettext-devel
BuildRequires:	libcrack-devel
BuildRequires:	pam-devel
BuildRequires:	python-devel
BuildRequires:	python3-devel

%description
The libpwquality library purpose is to provide common functions for password
quality checking and also scoring them based on their apparent randomness.

The library also provides a function for generating random passwords with good
pronounceability. The library supports reading and parsing of a configuration
file.

%package tools
Group:		System/Base
Summary:	Tools for password quality checking and generating random passwords
Requires:	cracklib-dicts
Provides:	%{oname} = %{version}-%{release}
Provides:	%{name} = %{version}-%{release}

%description tools
The libpwquality library purpose is to provide common functions for password
quality checking and also scoring them based on their apparent randomness.

The library also provides a function for generating random passwords with good
pronounceability. The library supports reading and parsing of a configuration
file.

%package -n %{libname}
Group:		System/Libraries
Summary:	Shared libraries for %{oname}
Requires:	%{name}-tools >= %{version}-%{release}

%description -n %{libname}
The libpwquality library purpose is to provide common functions for password
quality checking and also scoring them based on their apparent randomness.

%package -n %{devname}
Group:		Development/Other
Summary:	Files needed for developing PAM-aware applications and modules for PAM
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{oname}-devel = %{version}-%{release}
Conflicts:	%{name}-tools < 1.3.0

%description -n %{devname}
Files needed for development of applications using the libpwquality library.

%package -n python-pwquality
Group:		Development/Python
Summary:	Python bindings for the libpwquality library

%description -n python-pwquality
This is pwquality Python module that provides Python bindings for the
libpwquality library. These bindings can be used for easy password quality
checking and generation of random pronounceable passwords from Python
applications.

%package -n python3-pwquality
Group:		Development/Python
Summary:	Python bindings for the libpwquality library

%description -n python3-pwquality
This is pwquality Python module that provides Python bindings for the
libpwquality library. These bindings can be used for easy password quality
checking and generation of random pronounceable passwords from Python
applications.

%package -n pam_%{oname}
Summary:	PAM module to perform password quality checking
Group:		System/Libraries
Provides:	pam-%{oname} = %{version}-%{release}
Conflicts:	%{name}-tools < 1.3.0
Conflicts:	%{_lib}pwquality1 < 1.3.0

%description -n pam_%{oname}
PAM module that can be used instead of pam_cracklib to disallow weak new
passwords when user's login password is changed.

%prep
%setup -q
%autopatch -p1


# for python3 build
rm -rf %{py3dir}
cp -a . %{py3dir}

%build
#update autotool files
autoreconf -vfi
%configure2_5x \
	--with-securedir=%{_libdir}/security \
	--with-pythonsitedir=%{python2_sitearch} \
	--with-python-binary=%__python2 \
	--with-python-rev=%{python2_version} \
	--disable-static \
	--disable-rpath
%make

pushd %{py3dir}
autoreconf -vfi
%configure2_5x \
	--with-securedir=%{_libdir}/security \
	--with-pythonsitedir=%{python3_sitearch} \
	--with-python-binary=%__python3 \
	--with-python-rev=%{python3_version} \
	--disable-static \
	--disable-rpath
%make
popd

%install
%make_install

pushd %{py3dir}
%make_install -C python
popd

install -d %{buildroot}%{_sysconfdir}/security/pwquality.conf.d/

#we don't want these
find %{buildroot} -name "*.la" -delete

%find_lang %{name}

%files tools -f %{name}.lang
%license COPYING
%doc README NEWS AUTHORS
%config(noreplace) %{_sysconfdir}/security/%{oname}.conf
%dir %{_sysconfdir}/security/pwquality.conf.d/
%{_bindir}/pwmake
%{_bindir}/pwscore
%{_mandir}/man1/pwmake.1*
%{_mandir}/man1/pwscore.1*
%{_mandir}/man5/pwquality.conf.5*

%files -n %{libname}
%{_libdir}/%{name}.so.%{major}{,.*}

%files -n pam_%{oname}
%{_libdir}/security/pam_pwquality.so
%{_mandir}/man8/pam_pwquality.8*

%files -n %{devname}
%{_includedir}/%{oname}.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{oname}.pc
%{_mandir}/man3/pwquality.3*

%files -n python-pwquality
%{python2_sitearch}/pwquality-%{version}-py%{python2_version}.egg-info
%{python2_sitearch}/%{oname}.so

%files -n python3-pwquality
%{python3_sitearch}/pwquality-%{version}-py%{python3_version}.egg-info
%{python3_sitearch}/%{oname}.*.so


%changelog
* Thu Feb 11 2016 umeabot <umeabot> 1.3.0-4.mga6
+ Revision: 955619
- Mageia 6 Mass Rebuild

* Sat Oct 10 2015 daviddavid <daviddavid> 1.3.0-3.mga6
+ Revision: 888732
- use new python macros

  + ovitters <ovitters>
    - rebuild for new python3

* Sun Jul 26 2015 wally <wally> 1.3.0-2.mga6
+ Revision: 857891
- simplify python linking fix

* Sun Jul 26 2015 wally <wally> 1.3.0-1.mga6
+ Revision: 857826
- add patch to fix python3 build
- new version 1.3.0
- add support for python3
- split out pam_pwquality
- move man pages between pkgs

* Wed Oct 15 2014 umeabot <umeabot> 1.2.4-4.mga5
+ Revision: 749450
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.2.4-3.mga5
+ Revision: 726844
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.2.4-2.mga5
+ Revision: 681726
- Mageia 5 Mass Rebuild

* Thu Aug 07 2014 wally <wally> 1.2.4-1.mga5
+ Revision: 660944
- new version 1.2.4

* Sat Oct 19 2013 umeabot <umeabot> 1.2.3-2.mga4
+ Revision: 534775
- Mageia 4 Mass Rebuild

* Sat Sep 14 2013 wally <wally> 1.2.3-1.mga4
+ Revision: 478808
- new version 1.2.3

* Thu Jun 20 2013 wally <wally> 1.2.2-1.mga4
+ Revision: 445270
- new version 1.2.2

* Sat Jan 12 2013 umeabot <umeabot> 1.2.1-2.mga3
+ Revision: 358020
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 22 2012 wally <wally> 1.2.1-1.mga3
+ Revision: 333820
- new version 1.2.1

* Sat Aug 25 2012 wally <wally> 1.2.0-1.mga3
+ Revision: 283859
- new version 1.2.0
- fix some paths after /usr move

* Wed Jun 27 2012 wally <wally> 1.1.1-4.mga3
+ Revision: 264482
- add libpwquality-tools require to lib pkg (to get the config file)

* Wed Jun 27 2012 wally <wally> 1.1.1-3.mga3
+ Revision: 264445
- really fix devel pkg

* Wed Jun 27 2012 wally <wally> 1.1.1-2.mga3
+ Revision: 264435
- fix devel pkg

* Wed Jun 27 2012 wally <wally> 1.1.1-1.mga3
+ Revision: 264401
- import libpwquality (based to .spec from Fedora)

